aboutsummaryrefslogtreecommitdiff
path: root/azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs
diff options
context:
space:
mode:
Diffstat (limited to 'azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs')
-rwxr-xr-xazalea-protocol/src/packets/login/clientbound_custom_query_packet.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs b/azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs
index 05310fb0..515fb089 100755
--- a/azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs
+++ b/azalea-protocol/src/packets/login/clientbound_custom_query_packet.rs
@@ -1,9 +1,9 @@
use azalea_buf::{McBuf, UnsizedByteArray};
use azalea_core::ResourceLocation;
-use packet_macros::LoginPacket;
+use packet_macros::ClientboundLoginPacket;
use std::hash::Hash;
#[derive(Hash, Clone, Debug, McBuf, LoginPacket)]
pub struct ClientboundCustomQueryPacket {
#[var]
pub transaction_id: u32,
@@ -1,9 +1,9 @@
use std::hash::Hash;
-#[derive(Hash, Clone, Debug, McBuf, LoginPacket)]
+#[derive(Hash, Clone, Debug, McBuf, ClientboundLoginPacket)]
pub struct ClientboundCustomQueryPacket {
#[var]